How To Pack Everything for Your 3-Day Weekend Trip: The GQ Eye: GQ on Style: GQ
Author: GQ Magazine
Description: Ahhh, at last, Memorial Day weekend. The sweet sweet reminder that summer has officially arrived. It's just crab cakes and football straight through Labor Day, right? Yeah. Well, if you find yourself celebrating the
Keywords: GQ Magazine Online, GQ Magazine, Men's Fashion Magazine, Men's Lifestyle Magazine, Subscribe, Men's Fashion, Men's Lifestyle, Women of GQ, Style Guide, Style, Fashion, Women, Politics, Entertainment
Date: 2009-09-02T00:00:00-04:00

The GQ Eye
Close

- GQ
- Style
- The GQ Eye: GQ on Style

- Print
- Feeds

## The GQ Eye

- Tweet

On May 23, 2014 at 1:30 PM

## How To Pack Everything for Your 3-Day Weekend Trip

By John Jannuzzi

Ahhh, at last, Memorial Day weekend. The sweet sweet reminder that summer has officially arrived. It's just crab cakes and football straight through Labor Day, right? Yeah. Well, if you find yourself celebrating the return of the season with a road trip, but have yet to pack, we've got your back. You'll be traveling with everything you need in no time. All you have to do is pay close attention to the following.

First, make sure your trusty weekender is ready to go. If you're bringing a suit, better go with a garment bag.

Grab your toiletry kit, a 3-day weekend is not the time to let your skin down.

Make sure you bring sunscreen. It's about your health, it's important.

Don't just throw everything in your weekender, guys. There's an art to folding. Learn it. Live it. Love it.

Planning on going for a swim? You'll need one of these. Not the board shorts you bought a few summers ago. Forget about those. Forever.

Skip the running shoes, you don't need those when you've got this.

Throw in a good book for the beach, the train, or wherever.

And remember, don't show up at somebody's house empty-handed.

Tags:

- How-To,
- Packing,
- Travel

- Permalink
- Comments

- Last Night’s Must-See Menswear: Justin Bieber Tries Some Things
- GQ Selects: Converse 1970s Chuck Taylor Canvas Sneakers
- Follow @GQMagazine
- The GQ Eye: GQ on Style main

- Tweet
- E-Mail

## Entertainment

- The Bachelor's Chris Harrison Is Single
- Meet the New Jack O'Connell
- The Dark Side of the Moon
- Amen! (D'Angelo's Back)
- The Vladimir Putin Boardgame
- Chris Hemsworth: The Manliest Man in Hollywood

## News + Politics

- The Ghosts of Afghanistan Will Show Up Everywhere (Even on the Set of Breaking Bad)
- Kent Brantly: The First American to Contract Ebola
- Are You Ready for the Singularity?
- Robert Draper Investigates Robert Durst, Cross-Dressing Real Estate Scion
- Can Scott Walker Unite the Republicans?
- Meet George Zimmerman's Family | GQ

## Food + Travel

- David Chang's Kitchen: Don't Get All "Fresh" with Me
- David Chang's Kitchen: Your Idea of Bologna is Total Baloney
- Chart: The Family Tree of Bourbon Whiskey
- Recipe: Semi-Summer Salad - Chef Jeff Taibe of Oak + Almond
- The Great Franco-Italian Pasta Experiment
- How to Pick from an Overpriced Restaurant Wine List

## Women

- Can Women Be Douchebags?
- Man Repeller: In Defense of the Slutty Halloween Costume
- Before They Were Famous: 16 Music Video Vixens
- The Beyoncé Outtakes
- Miss Millennium: Beyoncé
- Video: Geezer Style: How to Get the Look

## Most Popular

### Around the Web

#### Follow Us On...

- ###### Follow GQ on Twitter

  Follow @GQmagazine @GQmagazine

  Follow @GQfashion @GQfashion

  Follow @GQpolitics @GQpolitics

- ###### Follow GQ on Tumblr

  gq.tumblr.com

  gqfashion.tumblr.com

- ###### Follow GQ on Pinterest

  GQ Magazine pinterest.com/gqmagazine

- ###### Follow GQ on Instagram

  Follow GQ on Instagram

E-mail Address

- ### GQ SHARP + SMART (Daily)

  Send me fresh style tips, breaking celebrity news, insider info, and more every day.

- ### YOUR WEEKLY GQ

  Send me the top stories in style, women, entertainment and more in one e-mail a week.

I understand and agree that registration on or use of this site constitutes agreement to it's user agreement & privacy policy.

## New on GQ.com

### America's Bartender - Essentials for an Awesome Home Bar

The most important aspect to making cocktails is having the right ingredients. Gary helps break it down by showing what you... more >

- The Bachelor's Chris Harrison Is Single

- What to Wear Today: January

- New Year, New 'Do

x